Method: SoftLayer::Client#network_timeout
- Defined in:
- lib/softlayer/Client.rb
#network_timeout ⇒ Object (readonly)
An integer value (in seconds). The number of seconds to wait for HTTP requests to the network API until they timeout. This value can be nil in which case the timeout will be the default value for the library handling network communication (often 30 seconds)
39 40 41 |
# File 'lib/softlayer/Client.rb', line 39 def network_timeout @network_timeout end |