Class: SoftLayer::UserCustomerExternalBinding
- Includes:
- DynamicAttribute
- Defined in:
- lib/softlayer/UserCustomerExternalBinding.rb
Overview
Each SoftLayer UserCustomerExternalBinding instance provides information for a single user customer’s external binding.
This class roughly corresponds to the entity SoftLayer_User_Customer_External_Binding in the API.
Instance Attribute Summary
Attributes inherited from ModelBase
Instance Method Summary collapse
-
#active ⇒ Object
:attr_reader: The flag that determines whether the external binding is active will be used for authentication or not.
-
#created ⇒ Object
:attr_reader: The date that the external authentication binding was created.
-
#note ⇒ Object
An optional note for identifying the external binding.
-
#password ⇒ Object
:attr_reader: The password used to authenticate the external id at an external authentication source.
-
#service ⇒ Object
Returns the service for interacting with this user customer extnerla binding through the network API.
-
#type ⇒ Object
The user friendly name of a type of external authentication binding.
-
#vendor ⇒ Object
The user friendly name of an external binding vendor.
Methods included from DynamicAttribute
Methods inherited from ModelBase
#[], #has_sl_property?, #initialize, #refresh_details, sl_attr, #to_ary
Constructor Details
This class inherits a constructor from SoftLayer::ModelBase
Instance Method Details
#active ⇒ Object
:attr_reader: The flag that determines whether the external binding is active will be used for authentication or not.
22 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 22 sl_attr :active |
#created ⇒ Object
:attr_reader: The date that the external authentication binding was created.
27 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 27 sl_attr :created, 'createDate' |
#note ⇒ Object
An optional note for identifying the external binding.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 37 sl_dynamic_attr :note do |resource| resource.should_update? do #only retrieved once per instance @note == nil end resource.to_update do self.service.getNote end end |
#password ⇒ Object
:attr_reader: The password used to authenticate the external id at an external authentication source.
33 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 33 sl_attr :password |
#service ⇒ Object
Returns the service for interacting with this user customer extnerla binding through the network API
80 81 82 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 80 def service softlayer_client[:User_Customer_External_Binding].object_with_id(self.id) end |
#type ⇒ Object
The user friendly name of a type of external authentication binding.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 50 sl_dynamic_attr :type do |resource| resource.should_update? do #only retrieved once per instance @type == nil end resource.to_update do type = self.service.getType type['name'] end end |
#vendor ⇒ Object
The user friendly name of an external binding vendor.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/softlayer/UserCustomerExternalBinding.rb', line 64 sl_dynamic_attr :vendor do |resource| resource.should_update? do #only retrieved once per instance @vendor == nil end resource.to_update do vendor = self.service.getVendor vendor['name'] end end |