Method: SoftLayer::VirtualServer#activeTransaction
- Defined in:
- lib/softlayer/VirtualServer.rb
#activeTransaction ⇒ Object
:attr_reader: The active transaction (if any) for this virtual server. Transactions are used to make configuration changes to the server and only one transaction can be active at a time.
DEPRECATION WARNING: This attribute is deprecated in favor of active_transaction and will be removed in the next major release.
58 |
# File 'lib/softlayer/VirtualServer.rb', line 58 sl_attr :activeTransaction |